==> huaweicloudsdkcodeartsdeploy-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/check_can_create_response_body_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckCanCreateResponseBodyResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'creatable': 'bool'
    }

    attribute_map = {
        'creatable': 'creatable'
    }

    def __init__(self, creatable=None):
        """CheckCanCreateResponseBodyResult

        The model defined in huaweicloud sdk

        :param creatable: 是否具有创建应用的权限
        :type creatable: bool
        """
        
        

        self._creatable = None
        self.discriminator = None

        if creatable is not None:
            self.creatable = creatable

    @property
    def creatable(self):
        """Gets the creatable of this CheckCanCreateResponseBodyResult.

        是否具有创建应用的权限

        :return: The creatable of this CheckCanCreateResponseBodyResult.
        :rtype: bool
        """
        return self._creatable

    @creatable.setter
    def creatable(self, creatable):
        """Sets the creatable of this CheckCanCreateResponseBodyResult.

        是否具有创建应用的权限

        :param creatable: The creatable of this CheckCanCreateResponseBodyResult.
        :type creatable: bool
        """
        self._creatable = creatable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckCanCreateResponseBodyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsdeploy-3.1.149-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/check_can_create_response_body_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckCanCreateResponseBodyResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'creatable': 'bool'
    }

    attribute_map = {
        'creatable': 'creatable'
    }

    def __init__(self, creatable=None):
        r"""CheckCanCreateResponseBodyResult

        The model defined in huaweicloud sdk

        :param creatable: 是否具有创建应用的权限
        :type creatable: bool
        """
        
        

        self._creatable = None
        self.discriminator = None

        if creatable is not None:
            self.creatable = creatable

    @property
    def creatable(self):
        r"""Gets the creatable of this CheckCanCreateResponseBodyResult.

        是否具有创建应用的权限

        :return: The creatable of this CheckCanCreateResponseBodyResult.
        :rtype: bool
        """
        return self._creatable

    @creatable.setter
    def creatable(self, creatable):
        r"""Sets the creatable of this CheckCanCreateResponseBodyResult.

        是否具有创建应用的权限

        :param creatable: The creatable of this CheckCanCreateResponseBodyResult.
        :type creatable: bool
        """
        self._creatable = creatable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckCanCreateResponseBodyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
